Coverage for D:\Ralf Gerlich\git\modypy\modypy\model\__init__.py: 100%

# Coverage for D:\Ralf Gerlich\git\modypy\modypy\model\__init__.py : 100%

## 4 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 from .events import EventPort, Clock, ZeroCrossEventSource

2 from .ports import Port, Signal, InputSignal, signal_method, signal_function, \

3 ShapeMismatchError, MultipleSignalsError, PortNotConnectedError

4 from .states import State, SignalState

5 from .system import System, Block, SystemState